======
fracpy
======

|travis-build| |coverage|

Fractal library

.. |travis-build| image:: https://travis-ci.org/grihabor/fracpy.svg?branch=master
    :target: https://travis-ci.org/grihabor/fracpy
    
.. |coverage| image:: https://coveralls.io/repos/github/grihabor/fracpy/badge.svg?branch=add-coverage
    :target: https://coveralls.io/github/grihabor/fracpy?branch=add-coverage
